@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.101';
+our $VERSION = '0.102';
 use 5.006;
 use strict;
 use warnings;
@@ -61,7 +61,8 @@ sub run {
 	$j->{_application}->build_terse($j) if $j->{_application}->can('build_terse');
 
 	$j->{_application_has_dispatcher} = !! $j->{_application}->can('dispatch');
-
+	$j->{_application_has_response_handler} = !! $j->{_application}->can('response_handle');
+	
 	my $content_type = $j->request->content_type;
 	if ($content_type && $content_type =~ m/application\/json/) {
 		$j->graft('params', $j->request->raw_body || "{}");
@@ -129,6 +130,7 @@ sub run {
 
 sub _response {
 	my ($self, $response_body, $cookie, $status) = @_;
+	return $self->{_application}->response_handle(@_) if $self->{_application_has_response_handler};
 	my $res = $self->request->new_response($response_body->status_code ||= $status ||= 200);
 	$res->cookies->{sid} = $cookie if $cookie;
 	$res->content_type('application/json');
@@ -274,7 +276,7 @@ Terse - lightweight JSON APIs.
 
 =head1 VERSION
 
-Version 0.101
+Version 0.102
 
 =cut
 
