@@ -11,13 +11,35 @@ sub start {
 	my $path = $pkg->_path($pkg);
 	my $self = $pkg->new(
 		app => 1,
-		controllers => $pkg->_build_controllers($pkg, $path),
 		models => $pkg->_build_models($pkg, $path),
+		views => $pkg->_build_views($pkg, $path),
+		controllers => $pkg->_build_controllers($pkg, $path),
 		@args
 	);
+	$self->build_app() if ($self->can('build_app'));
 	return $self;
 }
 
+
+sub _build_models {
+	my ($self, $pkg, $path) =@_; 
+	return $self->_load_modules(
+		path => $path,
+		pkg => $pkg,
+		type => 'Model'
+	);
+}
+
+
+sub _build_views {
+	my ($self, $pkg, $path) =@_; 
+	return $self->_load_modules(
+		path => $path,
+		pkg => $pkg,
+		type => 'View'
+	);
+}
+
 sub _build_controllers {
 	my ($self, $pkg, $path) =@_; 
 	return $self->_load_modules(
@@ -27,15 +49,6 @@ sub _build_controllers {
 	);
 }
 
-sub _build_models {
-	my ($self, $pkg, $path) =@_; 
-	return $self->_load_modules(
-		path => $path,
-		pkg => $pkg,
-		type => 'Model'
-	);
-}
-
 sub _load_modules {
 	my ($self, %args) = @_;
 	my $type = $args{type};
@@ -117,11 +130,11 @@ __END__;
 
 =head1 NAME
 
-Terse::App - Multiple controllers build an app.
+Terse::App - Lightweight MVC applications.
 
 =head1 VERSION
 
-Version 0.101
+Version 0.102
 
 =cut
 
