@@ -34,10 +34,17 @@ sub build_terse {
 	if ($self->controllers) {
 		$t->{controller} = sub {
 			my ($t, $controller) = @_;
-			$t->raiseError("invalid model: ${controller}", 400) unless $self->controllers->{$controller};
+			$t->raiseError("invalid controller: ${controller}", 400) unless $self->controllers->{$controller};
 			return $t->controllers->{$controller};
 		};
 	}
+	if ($self->views) {
+		$t->{view} = sub {
+			my ($t, $view) = @_;
+			$t->raiseError("invalid view: ${view}", 400) unless $self->views->{$view};
+			return $self->views->{$view};
+		};
+	}
 	return $t;
 }
 
@@ -79,6 +86,18 @@ sub PARSE_ATTRIBUTES {
 	return %attr;
 }
 
+sub response_handle {
+	my ($self, $t, $response_body, $cookie, $status) = @_;
+	my $res = $t->request->new_response($response_body->status_code ||= $status ||= 200);
+	$res->cookies->{sid} = $cookie if $cookie;
+	my ($content_type, $body) = $self->views->{$self->response_view} 
+		? $t->view($self->response_view)->render($t, $response_body) 
+		: ('application/json', $response_body->serialize());
+	$res->content_type($content_type);
+	$res->body($body);
+	return $res->finalize;
+}
+
 sub dispatch {
 	my ($self, $req, $t, @params) = @_;
 	my $package = ref $self || $self;
@@ -146,7 +165,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.101
+Version 0.102
 
 =cut
 
