@@ -13,7 +13,7 @@ sub hidden {
 }
 
 sub hello :get {
-	$_[1]->response->hello = "world";
+	$_[1]->response->hello = $_[1]->model('test')->something();
 }
 
 sub hello_get :get(hello_world) {
