@@ -3,9 +3,12 @@ package TestAppController;
 use base 'Terse::Controller';
 
 use TestAppController::Model;
+use TestAppController::View;
 
 sub build_controller {
 	$_[0]->models->test = TestAppController::Model->new();
+	$_[0]->views->test = TestAppController::View->new();
+	$_[0]->response_view = 'test';
 }
 
 sub hidden {
